body {
    padding-top: 50px;
    padding-bottom: 40px;
}
.sidebar-nav {
    padding: 9px 0;
}
.filter-nav .nav-header {
    font-size: 120%;
}

.filter-nav input {
    font-size: 11px !important;
}
.filter-nav input.pull-left {
    margin-right: 5px;
}

.filter-selected {
    background-color: #f4f4f4;
    border-radius: 5px;
}

.filter-selected .inputs {
    padding: 0 10px;
}
