{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <title>Django Queryset Reporter{% block title %}{% endblock %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="django queryset reporter is a django tool to generate and consume querys in a friendly way">
    <meta name="author" content="Ricardo Dani">

    <link href="{% static 'bootstrap/css/bootstrap-2.2.1.css' %}" rel="stylesheet">
    <link href="{% static 'bootstrap/css/bootstrap-2.2.1-datepicker.css' %}" rel="stylesheet">
    <link href="{% static 'queryset_reporter/queryset_reporter.css' %}" rel="stylesheet">
</head>
<body>
    {% block navigation %}
    <div class="navbar navbar-inverse navbar-fixed-top">
    <div class="navbar-inner">
        <div class="container-fluid">
        <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
        </a>
        <a class="brand" href="{% url 'queryset_reporter:qr_create' %}">Queryset Reporter</a>
        <div class="nav-collapse collapse">
            <p class="navbar-text pull-right">
            Logged in as <a href="#" class="navbar-link">{{ user }}</a>
            </p>
            <ul class="nav">
                <li class="active"><a href="{% url 'queryset_reporter:qr_create' %}">Criar relatório</a></li>
            </ul>
        </div>
        </div>
    </div>
    </div>
    {% endblock %}
    <div class="{% block content-class %}container-fluid{% endblock %}">
        {% block content %}
        {% endblock %}
        <hr>
        <footer>
            <p><strong>Django Queryset Reporter</strong> version {{ version }}</p>
        </footer>
    </div>
    <script src="{% static 'bootstrap/js/jquery-1.8.3.min.js' %}"></script>
    <script src="{% static 'bootstrap/js/bootstrap-2.2.1.js' %}"></script>
    <script src="{% static 'bootstrap/js/bootstrap-2.2.1-datepicker.js' %}"></script>
    <script src="{% static 'queryset_reporter/reporter.js' %}"></script>
    {% block extra-js %}
    {% endblock %}
</body>
</html>

