# Generated by Django 2.2.5 on 2019-10-03 01:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('queryset_reporter', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Exclude',
        ),
        migrations.DeleteModel(
            name='Filter',
        ),
        migrations.AlterModelOptions(
            name='queryfilter',
            options={'verbose_name': 'Filtro de query', 'verbose_name_plural': 'Filtros de query`s'},
        ),
        migrations.AlterModelOptions(
            name='queryset',
            options={'verbose_name': 'Modelo de Queryset', 'verbose_name_plural': 'Modelos de Queryset'},
        ),
        migrations.AlterField(
            model_name='queryfilter',
            name='method',
            field=models.CharField(choices=[('filter', 'Filtro'), ('exclude', 'Exclusão')], max_length=7, verbose_name='Método'),
        ),
        migrations.AlterField(
            model_name='queryset',
            name='distinct',
            field=models.BooleanField(default=False, verbose_name='Distinguir'),
        ),
        migrations.AlterField(
            model_name='queryset',
            name='model',
            field=models.ForeignKey(limit_choices_to={'pk__in': [2, 3, 4, 7, 8, 9, 10]}, on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType', verbose_name='Modelo'),
        ),
    ]
