# Generated by Django 2.2.6 on 2019-10-29 18:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('queryset_reporter', '0002_auto_20191003_0105'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='queryset',
            options={'permissions': (('can_use_reports', 'Prever e gerar relatórios'),), 'verbose_name': 'Modelo de Queryset', 'verbose_name_plural': 'Modelos de Queryset'},
        ),
    ]
